use std::path::PathBuf;

use askama::Template;

use crate::{common::materials::MaterialDrops, create_file};

const MATERIAL_KINDS: &[&str] = &[
	"blazing",
	"bright",
	"dark",
	"dense",
	"energy",
	"frost",
	"lightning",
	"lucid",
	"power",
	"remembrance",
	"serenity",
	"twilight",
];
const DROPS_PATH: &str = "./input/kh2/drops";

#[derive(Template)]
#[template(path = "pages/kh2/drops.html")]
struct DropsTemplate {
	pub drops: Vec<MaterialDrops>,
}

pub fn init() {
	tracing::info!("Loading enemy drops data from {}", DROPS_PATH);
	let drops = MaterialDrops::import(DROPS_PATH);

	tracing::info!("Generating the KH2 drops template");
	let drops_template = DropsTemplate { drops };

	create_file("./out/kh2", "drops", drops_template.render().unwrap()).unwrap();
}
